@@ -217,8 +217,8 @@ struct _MetaDisplay
   MetaKeyCombo overlay_key_combo;
   gboolean overlay_key_only_pressed;
   
-  /* Xinerama cache */
-  unsigned int xinerama_cache_invalidated : 1;
+  /* Monitor cache */
+  unsigned int monitor_cache_invalidated : 1;
 
   /* Opening the display */
   unsigned int display_opening : 1;
